==> openshift-model-miscellaneous-6.9.0-sources.jar: io/fabric8/openshift/api/model/miscellaneous/metal3/v1alpha1/ImageFluent.java <==
package io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.util.Map;
import java.util.LinkedHashMap;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class ImageFluent<A extends ImageFluent<A>> extends BaseFluent<A>{
  public ImageFluent() {
  }
  
  public ImageFluent(Image instance) {
    this.copyInstance(instance);
  }
  private String checksum;
  private String checksumType;
  private String format;
  private String url;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(Image instance) {
    instance = (instance != null ? instance : new Image());
  
    if (instance != null) {
        this.withChecksum(instance.getChecksum());
        this.withChecksumType(instance.getChecksumType());
        this.withFormat(instance.getFormat());
        this.withUrl(instance.getUrl());
        this.withChecksum(instance.getChecksum());
        this.withChecksumType(instance.getChecksumType());
        this.withFormat(instance.getFormat());
        this.withUrl(instance.getUrl());
        this.withAdditionalProperties(instance.getAdditionalProperties());
      }
  }
  
  public String getChecksum() {
    return this.checksum;
  }
  
  public A withChecksum(String checksum) {
    this.checksum=checksum; return (A) this;
  }
  
  public boolean hasChecksum() {
    return this.checksum != null;
  }
  
  public String getChecksumType() {
    return this.checksumType;
  }
  
  public A withChecksumType(String checksumType) {
    this.checksumType=checksumType; return (A) this;
  }
  
  public boolean hasChecksumType() {
    return this.checksumType != null;
  }
  
  public String getFormat() {
    return this.format;
  }
  
  public A withFormat(String format) {
    this.format=format; return (A) this;
  }
  
  public boolean hasFormat() {
    return this.format != null;
  }
  
  public String getUrl() {
    return this.url;
  }
  
  public A withUrl(String url) {
    this.url=url; return (A) this;
  }
  
  public boolean hasUrl() {
    return this.url != null;
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ImageFluent that = (ImageFluent) o;
    if (!java.util.Objects.equals(checksum, that.checksum)) return false;
  
    if (!java.util.Objects.equals(checksumType, that.checksumType)) return false;
  
    if (!java.util.Objects.equals(format, that.format)) return false;
  
    if (!java.util.Objects.equals(url, that.url)) return false;
  
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(checksum,  checksumType,  format,  url,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (checksum != null) { sb.append("checksum:"); sb.append(checksum + ","); }
    if (checksumType != null) { sb.append("checksumType:"); sb.append(checksumType + ","); }
    if (format != null) { sb.append("format:"); sb.append(format + ","); }
    if (url != null) { sb.append("url:"); sb.append(url + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  

}

==> openshift-model-miscellaneous-6.9.1-sources.jar: io/fabric8/openshift/api/model/miscellaneous/metal3/v1alpha1/ImageFluent.java <==
package io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.util.Map;
import java.util.LinkedHashMap;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class ImageFluent<A extends ImageFluent<A>> extends BaseFluent<A>{
  public ImageFluent() {
  }
  
  public ImageFluent(Image instance) {
    this.copyInstance(instance);
  }
  private String checksum;
  private String checksumType;
  private String format;
  private String url;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(Image instance) {
    instance = (instance != null ? instance : new Image());
    if (instance != null) {
          this.withChecksum(instance.getChecksum());
          this.withChecksumType(instance.getChecksumType());
          this.withFormat(instance.getFormat());
          this.withUrl(instance.getUrl());
          this.withChecksum(instance.getChecksum());
          this.withChecksumType(instance.getChecksumType());
          this.withFormat(instance.getFormat());
          this.withUrl(instance.getUrl());
          this.withAdditionalProperties(instance.getAdditionalProperties());
        }
  }
  
  public String getChecksum() {
    return this.checksum;
  }
  
  public A withChecksum(String checksum) {
    this.checksum = checksum;
    return (A) this;
  }
  
  public boolean hasChecksum() {
    return this.checksum != null;
  }
  
  public String getChecksumType() {
    return this.checksumType;
  }
  
  public A withChecksumType(String checksumType) {
    this.checksumType = checksumType;
    return (A) this;
  }
  
  public boolean hasChecksumType() {
    return this.checksumType != null;
  }
  
  public String getFormat() {
    return this.format;
  }
  
  public A withFormat(String format) {
    this.format = format;
    return (A) this;
  }
  
  public boolean hasFormat() {
    return this.format != null;
  }
  
  public String getUrl() {
    return this.url;
  }
  
  public A withUrl(String url) {
    this.url = url;
    return (A) this;
  }
  
  public boolean hasUrl() {
    return this.url != null;
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) {
      this.additionalProperties = null;
    } else {
      this.additionalProperties = new LinkedHashMap(additionalProperties);
    }
    return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ImageFluent that = (ImageFluent) o;
    if (!java.util.Objects.equals(checksum, that.checksum)) return false;
    if (!java.util.Objects.equals(checksumType, that.checksumType)) return false;
    if (!java.util.Objects.equals(format, that.format)) return false;
    if (!java.util.Objects.equals(url, that.url)) return false;
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(checksum,  checksumType,  format,  url,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (checksum != null) { sb.append("checksum:"); sb.append(checksum + ","); }
    if (checksumType != null) { sb.append("checksumType:"); sb.append(checksumType + ","); }
    if (format != null) { sb.append("format:"); sb.append(format + ","); }
    if (url != null) { sb.append("url:"); sb.append(url + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  

}
